Adding fix to initialize a dim3 variable from blockIdx. (#1212)
Adding gitignore for ctags
Αυτή η υποβολή περιλαμβάνεται σε:
υποβλήθηκε από
Maneesh Gupta
γονέας
797510614e
υποβολή
3e213d94e1
+1
-1
@@ -14,5 +14,5 @@ bin/hipBusBandwidth
|
||||
bin/hipDispatchLatency
|
||||
bin/hipify-clang
|
||||
include/hip/hcc_detail/hip_prof_str.h
|
||||
|
||||
tags
|
||||
samples/1_Utils/hipInfo/hipInfo
|
||||
|
||||
@@ -206,12 +206,15 @@ class Coordinates {
|
||||
|
||||
struct X {
|
||||
__device__ operator R() const { return f(0); }
|
||||
__device__ uint32_t operator=(R _) { return f(0); }
|
||||
};
|
||||
struct Y {
|
||||
__device__ operator R() const { return f(1); }
|
||||
__device__ uint32_t operator=(R _) { return f(1); }
|
||||
};
|
||||
struct Z {
|
||||
__device__ operator R() const { return f(2); }
|
||||
__device__ uint32_t operator=(R _) { return f(2); }
|
||||
};
|
||||
|
||||
public:
|
||||
|
||||
@@ -271,7 +271,7 @@ typedef struct dim3 {
|
||||
uint32_t y; ///< y
|
||||
uint32_t z; ///< z
|
||||
#ifdef __cplusplus
|
||||
dim3(uint32_t _x = 1, uint32_t _y = 1, uint32_t _z = 1) : x(_x), y(_y), z(_z){};
|
||||
__host__ __device__ dim3(uint32_t _x = 1, uint32_t _y = 1, uint32_t _z = 1) : x(_x), y(_y), z(_z){};
|
||||
#endif
|
||||
} dim3;
|
||||
|
||||
|
||||
Αναφορά σε νέο ζήτημα
Block a user